Module: Cul

Defined in:
lib/cul/preservation_utils/file_path.rb,
lib/cul/preservation_utils.rb,
lib/cul/preservation_utils/version.rb

Overview

Cul::PreservationUtils::FilePath The Filepath module provides utilities for validating that file names and file paths do not include any characters that may be problematic for preservation objects that will be stored in Google or Amazon cloud services. Additionally, this has the benefit of having matching names in both local copies of such Preservation objects and copies stored on the cloud.

Defined Under Namespace

Modules: PreservationUtils